"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _TBlockRenderer = _interopRequireDefault(require("./TBlockRenderer"));

var _TPhrasingRenderer = _interopRequireDefault(require("./TPhrasingRenderer"));

var _TTextRenderer = _interopRequireDefault(require("./TTextRenderer"));

var _SharedPropsProvider = require("./context/SharedPropsProvider");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * A component to render any {@link TNode}.
 */
const TNodeRenderer = /*#__PURE__*/(0, _react.memo)(function MemoizedTNodeRenderer(props) {
  const {
    tnode
  } = props;
  const sharedProps = (0, _SharedPropsProvider.useSharedProps)();
  const tnodeProps = { ...props,
    sharedProps
  };

  if (tnode.type === 'block' || tnode.type === 'document') {
    return /*#__PURE__*/_react.default.createElement(_TBlockRenderer.default, tnodeProps);
  }

  if (tnode.type === 'phrasing') {
    return /*#__PURE__*/_react.default.createElement(_TPhrasingRenderer.default, tnodeProps);
  }

  if (tnode.type === 'text') {
    return /*#__PURE__*/_react.default.createElement(_TTextRenderer.default, tnodeProps);
  }

  if (typeof __DEV__ === 'boolean' && __DEV__ && tnode.type === 'empty') {
    if (tnode.isUnregistered) {
      console.warn(`There is no custom renderer registered for tag "${tnode.tagName}" which is not part of the HTML5 standard. The tag will not be rendered.` + ' If you don\'t want this tag to be rendered, add it to "ignoredTags" prop array. If you do, register an HTMLElementModel for this tag with "customHTMLElementModels" prop.');
    } else if (tnode.tagName !== 'head') {
      console.warn(`The "${tnode.tagName}" tag is a valid HTML element but is not handled by this library. You must extend the default HTMLElementModel for this tag with "customHTMLElementModels" prop and make sure its content model is not set to "none".` + ' If you don\'t want this tag to be rendered, add it to "ignoredTags" prop array.');
    }
  }

  return null;
});
const defaultProps = {
  propsFromParent: {
    collapsedMarginTop: null
  }
}; // @ts-expect-error default props must be defined

TNodeRenderer.defaultProps = defaultProps;
var _default = TNodeRenderer;
exports.default = _default;
//# sourceMappingURL=TNodeRenderer.js.map