"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = TPhrasingRenderer;
exports.TDefaultPhrasingRenderer = void 0;

var _react = _interopRequireDefault(require("react"));

var _TChildrenRendererContext = require("./context/TChildrenRendererContext");

var _useAssembledCommonProps = _interopRequireDefault(require("./hooks/useAssembledCommonProps"));

var _renderTextualContent = _interopRequireDefault(require("./renderTextualContent"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const TDefaultPhrasingRenderer = ({
  children,
  ...props
}) => {
  const {
    tnode,
    propsForChildren
  } = props;
  const TNodeChildrenRenderer = (0, _TChildrenRendererContext.useTNodeChildrenRenderer)();
  const resolvedChildren = children !== null && children !== void 0 ? children : /*#__PURE__*/_react.default.createElement(TNodeChildrenRenderer, {
    tnode,
    propsForChildren
  });
  return (0, _renderTextualContent.default)(props, resolvedChildren);
};

exports.TDefaultPhrasingRenderer = TDefaultPhrasingRenderer;

function InnerTPhrasingRenderer(props) {
  const {
    assembledProps,
    Renderer
  } = (0, _useAssembledCommonProps.default)(props, TDefaultPhrasingRenderer);
  return /*#__PURE__*/_react.default.createElement(Renderer, assembledProps);
}

function isGhostTNode(tnode) {
  return tnode.type === 'text' && (tnode.data === '' || tnode.data === ' ') || tnode.type === 'empty';
}

function TPhrasingRenderer(props) {
  const TNodeChildrenRenderer = (0, _TChildrenRendererContext.useTNodeChildrenRenderer)(); // When a TPhrasing node is anonymous and has only one child, its
  // rendering amounts to rendering its only child.

  if (props.sharedProps.bypassAnonymousTPhrasingNodes && props.tnode.tagName == null && props.tnode.children.length <= 1) {
    return /*#__PURE__*/_react.default.createElement(TNodeChildrenRenderer, {
      tnode: props.tnode
    });
  }

  if (props.sharedProps.enableExperimentalGhostLinesPrevention && props.tnode.tagName == null && props.tnode.children.every(isGhostTNode)) {
    return null;
  }

  return /*#__PURE__*/_react.default.createElement(InnerTPhrasingRenderer, props);
}
//# sourceMappingURL=TPhrasingRenderer.js.map