"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getNativePropsForTNode;
const empty = {};
/**
 * Extract React Native props for a given {@link TNode}. Native props target
 * either `Text` or `View` elements, with an optional `onPress` prop for
 * interactive elements.
 *
 * @public
 */

function getNativePropsForTNode(props) {
  var _tnode$getReactNative, _ref;

  const {
    tnode,
    style,
    type,
    nativeProps,
    onPress
  } = props;
  const switchProp = type === 'block' ? props.viewProps : props.textProps;
  const propsFromModel = ((_tnode$getReactNative = tnode.getReactNativeProps()) === null || _tnode$getReactNative === void 0 ? void 0 : _tnode$getReactNative[type === 'block' ? 'view' : 'text']) || empty;
  const syntheticOnPress = (_ref = onPress !== null && onPress !== void 0 ? onPress : nativeProps === null || nativeProps === void 0 ? void 0 : nativeProps.onPress) !== null && _ref !== void 0 ? _ref : propsFromModel.onPress;
  const nextProps = { ...(typeof syntheticOnPress === 'function' ? {
      accessibilityRole: type === 'block' ? 'button' : 'link'
    } : null),
    ...propsFromModel,
    ...nativeProps,
    ...switchProp,
    onPress: syntheticOnPress,
    style: [style, nativeProps === null || nativeProps === void 0 ? void 0 : nativeProps.style, switchProp.style],
    testID: tnode.tagName || undefined
  };
  return nextProps;
}
//# sourceMappingURL=getNativePropsForTNode.js.map